@@ -19,10 +19,14 @@ public class ExtendedXMLJUnitResultFormatter extends XMLJUnitResultFormatter {
     public void startTestSuite(JUnitTest suite) {
         // テストケースディレクトリを取得。
         String dirs = System.getProperty(XMLJUnitTask.TEST_PROP_KEY_ROOT_DIRS);
+        // ディレクトリの深さを取得。
+        int depth = Integer.parseInt(System
+                .getProperty(XMLJUnitTask.TEST_PROP_KEY_DEPTH));
 
         if (dirs.indexOf(",") < 0) {
             // ディレクトリが１つの場合はディレクトリ名をテスト名にセット。
-            suite.setName(FileUtils.toDotSeparatedValue(dirs));
+            suite.setName(FileUtils.toDotSeparatedValue(FileUtils.trim(dirs,
+                    depth)));
         } else {
             // ディレクトリが複数の場合はXMLテストランナーのクラス名をテスト名にセット。
             suite.setName(XMLTestRunner.class.getName());
