@@ -51,6 +51,10 @@ public class DIConTestCase extends XMLTestCase {
 
         InjectedObjects injectedObjects = xml.getInjectedObjects();
 
+        if (injectedObjects != null) {
+            processCreate(injectedObjects);
+        }
+
         // 注入するオブジェクトを取得してコンポーネントを生成。
         Object component = buildComponent(target, type, injectedObjects);
 
@@ -77,13 +81,11 @@ public class DIConTestCase extends XMLTestCase {
                     .getClasses(), argument.getArguments());
 
             if (injectedObjects != null) {
-                processComponent(injectedObjects, injectedObjects
-                        .getSuccesses(), "success");
+                processSuccess(injectedObjects);
             }
         } catch (BodyBuilderException e) {
             if (injectedObjects != null) {
-                processComponent(injectedObjects,
-                        injectedObjects.getFailures(), "failure");
+                processFailure(injectedObjects);
             }
 
             // メソッドの例外ではない場合は上位に投げる。
@@ -96,8 +98,7 @@ public class DIConTestCase extends XMLTestCase {
             debug("'" + cause + "' was catched.");
         } finally {
             if (injectedObjects != null) {
-                processComponent(injectedObjects, injectedObjects.getWindUps(),
-                        "wind up");
+                processWindUp(injectedObjects);
             }
         }
 
@@ -219,11 +220,93 @@ public class DIConTestCase extends XMLTestCase {
         return component;
     }
 
+    /**
+     * 生成時の処理をする。
+     * 
+     * @param injectedObjects コンポーネント
+     */
+    private void processCreate(InjectedObjects injectedObjects) {
+        String[] names = injectedObjects.getNames();
+
+        for (int i = 0; i < names.length; i++) {
+            Object object = injectedObjects.getObject(names[i]);
+
+            if (object instanceof Component) {
+                debug("create process of component '" + names[i] + "'.");
+                ((Component) object).create();
+            }
+        }
+    }
+
+    /**
+     * 成功時の処理をする。
+     * 
+     * @param injectedObjects コンポーネント
+     */
+    private void processSuccess(InjectedObjects injectedObjects) {
+        String[] names = injectedObjects.getNames();
+
+        for (int i = 0; i < names.length; i++) {
+            Object object = injectedObjects.getObject(names[i]);
+
+            if (object instanceof Component) {
+                debug("success process of component '" + names[i] + "'.");
+                ((Component) object).success();
+            }
+        }
+
+        processComponent(injectedObjects, injectedObjects.getSuccesses(),
+                "success");
+    }
+
+    /**
+     * 失敗時の処理をする。
+     * 
+     * @param injectedObjects コンポーネント
+     */
+    private void processFailure(InjectedObjects injectedObjects) {
+        String[] names = injectedObjects.getNames();
+
+        for (int i = 0; i < names.length; i++) {
+            Object object = injectedObjects.getObject(names[i]);
+
+            if (object instanceof Component) {
+                debug("failure process of component '" + names[i] + "'.");
+                ((Component) object).failure();
+            }
+        }
+
+        processComponent(injectedObjects, injectedObjects.getFailures(),
+                "failure");
+    }
+
+    /**
+     * 終了時の処理をする。
+     * 
+     * @param injectedObjects コンポーネント
+     */
+    private void processWindUp(InjectedObjects injectedObjects) {
+        String[] names = injectedObjects.getNames();
+
+        for (int i = 0; i < names.length; i++) {
+            Object object = injectedObjects.getObject(names[i]);
+
+            if (object instanceof Component) {
+                debug("wind up process of component '" + names[i] + "'.");
+                ((Component) object).windup();
+            }
+        }
+
+        processComponent(injectedObjects, injectedObjects.getWindUps(),
+                "wind up");
+    }
+
     /**
      * コンポーネントの処理をする。
      * 
      * @param injectedObjects コンポーネント
      * @param methods メソッド
+     * @param processName プロセス名
      */
     private void processComponent(InjectedObjects injectedObjects, Map methods,
             String processName) {
