@@ -5,10 +5,14 @@ import java.lang.reflect.Constructor;
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
+import java.lang.reflect.Modifier;
 import java.lang.reflect.Proxy;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
+
 import bodybuilder.exception.BodyBuilderException;
 
 /**
@@ -194,6 +198,69 @@ public class ObjectUtils {
         }
     }
 
+    /////////////////////////////////////////////////////////////////
+    // array method
+
+    /**
+     * 配列かどうか判定する。
+     * 
+     * @param type 型
+     * @return 配列の場合はtrue
+     */
+    public static boolean isArray(String type) {
+        return type.matches("^[^\\[]+(\\[\\])+$");
+    }
+
+    /**
+     * 配列のクラス名を取得する。
+     * 
+     * @param type 型
+     * @return 配列のクラス名
+     */
+    public static String getArrayClassName(String type) {
+        Pattern pattern = Pattern.compile("^([^\\[]+)((\\[\\])+)$");
+        Matcher matcher = pattern.matcher(type);
+
+        if (!matcher.matches()) {
+            return null;
+        }
+
+        String componentType = matcher.group(1);
+        String dimension = matcher.group(2);
+        StringBuffer arrayType = new StringBuffer();
+        int plane = dimension.length() / 2;
+
+        for (int i = 0; i < plane; i++) {
+            arrayType.append("[");
+        }
+
+        if ("bool".equals(componentType) || "boolean".equals(componentType)) {
+            arrayType.append("Z");
+        } else if ("byte".equals(componentType)) {
+            arrayType.append("B");
+        } else if ("char".equals(componentType)
+                || "character".equals(componentType)) {
+            arrayType.append("C");
+        } else if ("short".equals(componentType)) {
+            arrayType.append("S");
+        } else if ("int".equals(componentType)
+                || "integer".equals(componentType)) {
+            arrayType.append("I");
+        } else if ("long".equals(componentType)) {
+            arrayType.append("J");
+        } else if ("float".equals(componentType)) {
+            arrayType.append("F");
+        } else if ("double".equals(componentType)) {
+            arrayType.append("D");
+        } else {
+            arrayType.append("L");
+            arrayType.append(componentType);
+            arrayType.append(";");
+        }
+
+        return arrayType.toString();
+    }
+
     /////////////////////////////////////////////////////////////////
     // class getter
 
@@ -670,7 +737,7 @@ public class ObjectUtils {
      * @return スタティックメソッドの場合はtrue
      */
     public static boolean isStaticMethod(Method method) {
-        return method.toString().matches("^.* static .*$");
+        return Modifier.isStatic(method.getModifiers());
     }
 
     /////////////////////////////////////////////////////////////////
@@ -789,4 +856,60 @@ public class ObjectUtils {
         return instance_of(obj, type.getName());
     }
 
+    /////////////////////////////////////////////////////////////////
+    // package getter
+
+    /**
+     * 指定されたオブジェクトのパッケージ名を取得する。
+     * 
+     * @param clazz クラス
+     * @param asterisk アスタリスクをつけるかどうかのフラグ
+     * @return パッケージ名
+     */
+    public static String getPackage(String clazz, boolean asterisk) {
+        int index = clazz.lastIndexOf('.');
+
+        if (index < 0) {
+            return "";
+        }
+
+        String pkg = clazz.substring(0, index);
+
+        return asterisk ? pkg + ".*" : pkg;
+    }
+
+    /**
+     * 指定されたクラスのパッケージ名を取得する。
+     * 
+     * @param clazz クラス
+     * @return パッケージ名
+     */
+    public static String getPackage(String clazz) {
+        return getPackage(clazz, false);
+    }
+
+    /**
+     * 指定されたクラスのパッケージ名を取得する。
+     * 
+     * @param clazz クラス
+     * @return パッケージ名
+     */
+    public static String getPackage(Class clazz) {
+        return getPackage(clazz.getName());
+    }
+
+    /**
+     * 指定されたオブジェクトのパッケージ名を取得する。
+     * 
+     * @param obj オブジェクト
+     * @return パッケージ名
+     */
+    public static String getPackage(Object obj) {
+        if (obj == null) {
+            return "";
+        }
+
+        return getPackage(obj.getClass().getName());
+    }
+
 }
\ No newline at end of file
