@@ -12,7 +12,8 @@ public class StandardOutputHandler extends AbstractOutputHandler {
      */
     public StandardOutputHandler() {
         // 出力先を標準出力にする。
-        super(new PrintWriter(System.out, true), "  ");
+        printWriter = new PrintWriter(System.out, true);
+        tab = "  ";
     }
 
 }
\ No newline at end of file
